%%%==============================================================================
%% Copyright 2022-23 by Alceu Frigeri
%%
%% This work may be distributed and/or modified under the conditions of
%%
%% * The [LaTeX Project Public License](http://www.latex-project.org/lppl.txt),
%%   version 1.3c (or later), and/or
%% * The [GNU Affero General Public License](https://www.gnu.org/licenses/agpl-3.0.html),
%%   version 3 (or later)
%%
%% This work has the LPPL maintenance status *maintained*.
%%
%% The Current Maintainer of this work is Alceu Frigeri
%%
%% This is version 1.0.8 (2023/01/28)
%%
%% The list of files that compose this work can be found in the README.md file at
%% https://ctan.org/pkg/ufrgscca
%%
%%%==============================================================================
%% UFRGS stands for "Federal University of Rio Grande do Sul" in south Brazil
%% EE    stands for "Engineering School"
%% CCA   stands for "Control and Automation Engineering Course" (Portuguese acronym)
%%%==============================================================================
\makeatletter
\def\tc@tmp@packname{ufrgscca-ptBR-core}
\def\tc@tmp@altpackname{ufrgsccaptbrcore}
\def\tc@tmp@packdesc{UFRGS/CCA Portuguese core defs}
\def\tc@tmp@packdate{2023/01/28}
\def\tc@tmp@packversion{1.0.8}
\let\@exp\expandafter
\@exp\edef\csname\tc@tmp@altpackname version\endcsname{\tc@tmp@packversion}


\location{Porto~Alegre}{RS}

\university{Universidade Federal do Rio Grande do Sul}
\universityacronym{UFRGS}
\universitydivision{Escola de Engenharia}
\divisiongradcouncil{Conselho de Graduação da \tcdef@cover@universitydivision}

\secretaryacronym{SACAD}
\secdivisionacronym{\tcdef@cover@secretaryacronym/EE}
\graduationtitle{Bacharel em Eng. de Controle e Automa\c{c}\~{a}o}
\course{Eng. de Controle e Automa\c{c}\~{a}o}
\courseacronym{CCA}
\coursecoord{Atual Coordenador(a) do Curso}
\coursecoordtitle{Coordenador\tccore@@ref{coursecoord}{narticle} de curso}
\advisorname{Orientador\tccore@@ref{advisor}{narticle}}%
\coadvisorname{Co-orientador\tccore@@ref{coadvisor}{narticle}}%

\iftcif@nonrequired
  \internshiptitle{Relatório de Estágio Não Obrigatório}
\else
  \internshiptitle{Relatório de Estágio Supervisionado Obrigatório em \tcdef@cover@course}
\fi

\internshipcoord{Atual Coordenador(a) de Estágios}
\internshipcoordtitle{Coord\tccore@@ref{internshipcoord}{narticle}. da Atividade de Estágio Supervisionado Obrigatório}

\iftcif@nonrequired
    \internshipinfo{%
    Este Relatório foi julgado adequado para a \textsl{Atividade de Estágio Não Obrigatório}
    em \emph{\tcdef@cover@course\ } e aprovado em sua forma final pel\tccore@@ref{tutor}{article} Tutor\tccore@@ref{tutor}{narticle} e
    Supervisor\tccore@@ref{supervisor}{narticle}.
}%
\else
    \internshipinfo{%
    Este Relatório foi julgado adequado para a obtenção do conceito final na \textsl{Atividade de Estágio Supervisionado Obrigatório}
    em \emph{\tcdef@cover@course\ } e aprovado em sua forma final pel\tccore@@ref{tutor}{article} Tutor\tccore@@ref{tutor}{narticle},
    Supervisor\tccore@@ref{supervisor}{narticle} e Coordenador\tccore@@ref{internshipcoord}{narticle} da Atividade.
    }%
\fi


\examinername{Banca Examinadora}%

\reportspecificinfo{%
		Trabalho de Conclus\~{a}o de Curso (TCC-\tcdef@cover@courseacronym ) apresentado \`{a}
		COMGRAD-\tcdef@cover@courseacronym\  da \tcdef@cover@university\ como parte dos requisitos para a
		obten{\c{c}}{\~a}o do t\'{\i}tulo de \emph{\tcdef@cover@graduationtitle\ }.
}%

\approvalspecificinfo{%
		Este Trabalho de Conclus\~{a}o de Curso foi julgado adequado para a
		obten\c{c}\~ao dos cr\'editos da Disciplina de TCC do curso \emph{\tcdef@cover@course\ } e aprovado em sua forma final pel\tccore@@ref{advisor}{article}
		Orientador\tccore@@ref{advisor}{narticle} e pela Banca Examinadora.
}%

\profname{Professor\tccore@@ref{advisor}{narticle}}
\coprofname{Professor\tccore@@ref{coadvisor}{narticle}}
\tutorname{Tutor\tccore@@ref{tutor}{narticle}}
\supervisorname{Supervisor\tccore@@ref{supervisor}{narticle}}


