% Peking University dissertation document class
%
% Copyright (c) 2008-2009 solvethis
% Copyright (c) 2010-2013,2015,2021 Casper Ti. Vector
%
% This work may be distributed and/or modified under the conditions of the
% LaTeX Project Public License, either version 1.3 of this license or (at
% your option) any later version.
% The latest version of this license is in
%   https://www.latex-project.org/lppl.txt
% and version 1.3 or later is part of all distributions of LaTeX version
% 2005/12/01 or later.
%
% This work has the LPPL maintenance status `maintained'.
% The current maintainer of this work is Casper Ti. Vector.
%
% This work consists of the following files:
%   pkuthss.cls
%   pkuthss.def
%   pkuthss-gbk.def
%   pkuthss-utf8.def
%   pkulogo.eps
%   pkuword.eps

\ProvidesFile{pkuthss.def}
	[2022/10/30 v1.9.3 Labels and captions for the pkuthss document class]

\def\label@ementor{Directed by\ }
\def\euniversity{Peking University}
\def\ethesisname{Doctor Thesis}
\def\thesiscover{}
\def\mentorlines{1}
\def\eabstractname{ABSTRACT}

\ifthss@opt@ugly
	\def\label@ekeywords{KEY WORDS:\ }
\else
	\def\label@ekeywords{KEYWORDS:\ }
\fi

\ifthss@opt@gbk
	\input{pkuthss-gbk.def}
	\ifxetex
		% No support for XeLaTeX compilation in non-unicode encoding, i.e. GBK.
		\ClassError{pkuthss}%
			{XeLaTeX compilation is not supported without UTF-8}%
			{%
				XeLaTeX compilation without UTF-8 is very problematic.\MessageBreak
				Therefore please use UTF-8 encoding for the LaTeX code.%
			}
	\fi
\else
	\input{pkuthss-utf8.def}
\fi

\endinput
% vim:ft=tex:ts=2:sw=2
