%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%    Series information:
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


\newcommand{\ahl}{ahl}
\newcommand{\algad}{algad}
\newcommand{\calseries}{calseries}
\newcommand{\cam}{cam}
\newcommand{\cib}{cib}
\newcommand{\cfls}{cfls}	%Conceptual Foundation of the Language Sciences
\newcommand{\cogl}{cogl}	%SIDL-CoGL
\newcommand{\classics}{classics}
\newcommand{\cmle}{cmle}	%Computational Models of Language Evolution
\newcommand{\eotms}{eotms}
\newcommand{\eotmsig}{eotmsig}
\newcommand{\eurosla}{eurosla}
\newcommand{\ela}{ela}
\newcommand{\hpls}{hpls}
\newcommand{\loc}{loc}
\newcommand{\lv}{lv}            %Language Variation
\newcommand{\mi}{mi}
\newcommand{\nc}{nc}		%Niger Congo
\newcommand{\ogs}{ogs}		%Open Generative Syntax
\newcommand{\ogl}{ogl}      %  Open Germanic Linguistics
\newcommand{\orl}{orl}		%Open Romance Linguistics
\newcommand{\osl}{osl}		%Open Slavic Linguistics
\newcommand{\pmwe}{pmwe}		%Phraseology and Multi-Word Expressions
\newcommand{\rcg}{rcg} %
\newcommand{\scl}{scl}
\newcommand{\sidl}{sidl}
\newcommand{\silp}{silp}	%Studies in Laboratory Phonology
\newcommand{\tbls}{tbls}	%Textbooks in Language Sciences
\newcommand{\tgdi}{tgdi}	%Topics at the  Grammar-Discourse Interface
\newcommand{\tmnlp}{tmnlp}
\newcommand{\tpd}{tpd}

\newcommand{\dummyseries}{dummyseries}
\newcommand{\guidelines}{guidelines}
\newcommand{\lsSeriesFontColor}{white}

\AtBeginDocument{
\ifx\lsSeries\ahl
	\newcommand{\lsSeriesTitle}{Advances in Historical Linguistics}
	\newcommand{\lsSeriesColor}{lsRed}
%	\renewcommand{\lsISSN}{}
	\renewcommand{\lsSeriesText}{
            Editors:
            Klaus Grübl (Leipzig University, Germany),
            Judith Huber (LMU Munich, Germany),
            Simon Pickl (University of Salzburg, Austria),
            Lea Schäfer (University of Düsseldorf, Germany),
            Markus Schiegg (University of Erlangen-Nürnberg, Germany)


            \bigskip

            In this series:

%            \begin{enumerate}
%            \item
%            \end{enumerate}
        }
\fi
\ifx\lsSeries\algad
	\newcommand{\lsSeriesTitle}{African Language Grammars \newlineCover and Dictionaries}
	\newcommand{\lsSeriesColor}{lsLightOrange}
	\renewcommand{\lsISSN}{2512-4862}
	\renewcommand{\lsSeriesText}{
            Chief Editor:    Adams Bodomo \\
            Editor:        Firmin Ahoua

            \bigskip

            In this series:

            \begin{enumerate}
            \item Schrock, Terrill B. The Ik language: Dictionary and grammar sketch.
            \item Brindle, Jonathan. A dictionary and grammatical outline of Chakali.
            \item Friesen, Dianne. A grammar of Moloko.
            \item Ali, Mark, Scott Grimm \& Adams Bodomo. A dictionary and  grammatical sketch of Dagaare.
            \item  Namyalo, Saudah,   Alena Witzlack-Makarevich,   Anatole Kiriggwajjo,   Amos Atuhairwe,   Zarina Molochieva,   Ruth Gimbo Mukama   \& Margaret Zellers. A dictionary and grammatical sketch of Ruruuli-Lunyala.
            \item Gunnink, Hilde. A grammar of Fwe.
            \end{enumerate}
        }
\fi
\ifx\lsSeries\calseries %\cal is already taken as a command
	\newcommand{\lsSeriesTitle}{Contemporary African Linguistics}
	\newcommand{\lsSeriesColor}{lsMidWine}
	\renewcommand{\lsISSN}{2511-7726}
	\renewcommand{\lsSeriesText}{
            {\large Contemporary African Linguistics}

            \bigskip

            Editors: Akinbiyi Akinlabi,  Laura J. Downing


            \bigskip

            In this series:

            \begin{enumerate}
            \item Payne, Doris L., Sara Pacchiarotti \& Mokaya Bosire (eds.). Diversity in African languages: Selected papers from the 46th Annual Conference on African Linguistics.
            \item Persohn, Bastian. The verb in Nyakyusa: A focus on tense, aspect and modality.
            \item Kandybowicz, Jason, Travis Major \& Harold Torrence (eds.). African linguistics on the prairie: Selected papers from the 45th Annual Conference on African Linguistics.
            \item Clem, Emily, Peter Jenks   \& Hannah Sande (eds.). Theory and description in African Linguistics: Selected papers from the 47th Annual Conference on African Linguistics.
            \item Lotven, Samson, Silvina Bongiovanni, Phillip Weirich, Robert Botne \& Samuel Gyasi Obeng (eds.). African linguistics across the disciplines: Selected papers from the 48th Annual Conference on African Linguistics.
            \item Sibanda, Galen, Deo Ngonyani, Jonathan Choti \& Ann Biersteker (eds.). Descriptive and theoretical approaches to African linguistics: Selected papers from the 49th Annual Conference on African Linguistics.
            \item Akinlabi, Akinbiyi, Lee Bickmore, Michael Cahill, Michael Diercks, Laura J. Downing, James Essegbey, Katie Franich, Laura McPherson \& Sharon Rose (eds.). Celebrating 50 years of ACAL: Selected papers from the 50th Annual Conference on African Linguistics.
            \end{enumerate}
            }
\fi
\ifx\lsSeries\cam
	\newcommand{\lsSeriesTitle}{Contact and Multilingualism}
	\newcommand{\lsSeriesColor}{lsRed} 
	\renewcommand{\lsISSNelectronic}{2700-855X}
 	\renewcommand{\lsISSNprint}{2700-8541} 
 	\renewcommand{\lsSeriesText}{
        {\large  Contact and Multilingualism}

        \bigskip

        Editors: Isabelle Léglise (CNRS SeDyL), Stefano Manfredi (CNRS SeDyL)  

        \bigskip

        In this series:

        \begin{enumerate}
          \item Lucas, Christopher \& Stefano Manfredi (eds.). Arabic and contact-induced change.
          \item Pinto, Jorge \& Nélia Alexandre (eds.).  Multilingualism and third language acquisition: Learning and teaching trends.
          \item Hakimov, Nikolay. Explaining Russian-German code-mixing: A usage-based approach.
          \item Sánchez Moreano, Santiago \& Élodie Blestel. Prácticas lingüísticas heterogéneas: Nuevas perspectivas para el estudio del español en contacto con lenguas amerindias.
          \item Migge, Bettina \& Shelome Gooden.  Social and structural aspects of language contact and change.
          \item Coler, Matt \& Andrew Nevins (eds.). Contemporary research in minoritized and diaspora languages of Europe.
        \end{enumerate}
        }
\fi

\ifx\lsSeries\cib
	\newcommand{\lsSeriesTitle}{Current Issues in Bilingualism}
	\newcommand{\lsSeriesColor}{lsLightGreen}
	\renewcommand{\lsISSNelectronic}{2747-9927}
 	\renewcommand{\lsISSNprint}{2747-9919} 
 	\renewcommand{\lsSeriesText}{
        {\large  Current Issues in Bilingualism}

        \bigskip

        Editors:     Andrea C. Schalley (Karlstad University, Sweden) [editor-in-chief],\\
    M Carmen Parafita Couto (Leiden University, Netherlands) [editor-in-chief],\\
    Susana Eisenchlas (Griffith University, Australia),\\
    Galina Putjata (Europa-Universität Flensburg, Germany),\\
    Jorge Valdés Kroff (University of Florida, USA).


        \bigskip

        In this series:

        \begin{enumerate}
          \item Shim, Ji Young. OV and VO variation in code-switching.
          \item Rodríguez González, Eva \& Rosita L. Rivera (eds.). Language assessment in multilingual settings: Innovative practices across formal and informal environments.
        \end{enumerate}
        }
\fi
\ifx\lsSeries\cfls
	\newcommand{\lsSeriesTitle}{Conceptual Foundations of \newlineCover Language Science}
	\newcommand{\lsSeriesColor}{lsNightGreen}
	\renewcommand{\lsISSN}{2363-877X}
	\renewcommand{\lsSeriesText}{
            {\large Conceptual Foundations of Language Science}

            \bigskip

            \textbf{Series editors}\\
            Mark Dingemanse, \textit{Radboud University}\\
            N. J. Enfield, \textit{University of Sydney}


            \bigskip


            \textbf{Editorial board}\\
            Balthasar Bickel, \textit{University of Zürich},
            Claire Bowern, \textit{Yale University},
            Elizabeth Couper-Kuhlen, \textit{University of Helsinki},
            William Croft, \textit{University of New Mexico},
            Rose-Marie Déchaine, \textit{University of British Columbia},
            William A. Foley, \textit{University of Sydney},
            William F. Hanks, \textit{University of California at Berkeley},
            Paul Kockelman, \textit{Yale University},
            Keren Rice, \textit{University of Toronto},
            Sharon Rose, \textit{University of California at San Diego},
            Frederick J. Newmeyer, \textit{University of Washington},
            Wendy Sandler, \textit{University of Haifa},
            Dan Sperber, \textit{Central European University}


            \bigskip

            \begin{minipage}{\textwidth}% for undoing \raggedright and justify the following two paragraphs

            No scientific work proceeds without conceptual foundations. In language science, our concepts about language determine our assumptions, direct our attention, and guide our hypotheses and our reasoning. Only with clarity about conceptual foundations can we pose coherent research questions, design critical experiments, and collect crucial data.
            %
            This series publishes short and accessible books that explore well-defined topics in the conceptual foundations of language science. The series provides a venue for conceptual arguments and explorations that do not require the traditional book-length treatment, yet that demand more space than a typical journal article allows.
            \end{minipage}

            \bigskip

            \textbf{In this series:}

            \begin{enumerate}
            \item Enfield, N. J. {Natural causes of language}.
            \item Müller, Stefan. {A lexicalist account of argument structure: Template-based phrasal LFG approaches and a lexical HPSG alternative}.
            \item Schmidtke-Bode, Karsten,  Natalia Levshina, Susanne Maria Michaelis \& Ilja A. Seržant (eds.).  Explanation in typology: Diachronic sources, functional motivations and the nature of the evidence.
            \item Morley, Rebecca L. Sound structure and sound change: A modeling approach.
            \item Asoulin, Eran. Language and scientific explanation: Where does semantics fit in?
            \item Boeckx, Cedric. Reflections on language evolution: From minimalism to pluralism.
            \item Archangeli, Diana \& Douglas Pulleyblank. Emergent phonology.
            \item Lund, Kristine, Pierluigi Basso Fossali, Audrey Mazur \& Magali Ollagnier-Beldame (eds.). Language is a complex adaptive system: Explorations and evidence.
            \end{enumerate}

            }
\fi
\ifx\lsSeries\cogl
	\newcommand{\lsSeriesTitle}{Comprehensive Grammar Library}
	\newcommand{\lsSeriesColor}{lsNightBlue}
	\renewcommand{\lsISSNelectronic}{2749-7798}
 	\renewcommand{\lsISSNprint}{2748-971X} 
	\renewcommand{\lsSeriesText}{
            {\large Comprehensive Grammar Library}

            \bigskip
            Editor: Martin Haspelmath

            \bigskip
            In this series:

            \begin{enumerate}
            \item Jacques, Guillaume. A grammar of Japhug.
            \item Grimm, Nadine. A grammar of Gyeli.
            \item Maurer-Cecchini, Philippe. A grammar of Tuatschin: A Sursilvan Romansh dialect.
            \item Visser, Eline. A grammar of Kalamang.
            \item Caballero, Gabriela. A grammar of Choguita Rarámuri: In collaboration with Luz Elena León Ramírez, Sebastián Fuentes Holguín, Bertha Fuentes Loya and other Choguita Rarámuri language experts.
            \end{enumerate}


            This  series grew out of  the grammars published in \textit{Studies in Diversity Linguistics}, which are proudly mentioned:

            \begin{enumerate}
            \item[4.] Berghäll, Liisa. A grammar of Mauwake.
            \item[5.] Wilbur, Joshua. A grammar of Pite Saami.
            \item[7.] Schackow, Diana.    A grammar of Yakkha.
            \item[8.] Liljegren, Henrik. A grammar of Palula.
            \item[9.] Shimelman, Aviva. A grammar of Yauyos Quechua.
            \item[11.] Kluge, Angela. A grammar of Papuan Malay.
            \item[12.] Kieviet, Paulus. A grammar of Rapa Nui.
            \item[22.] Döhler, Christian. A grammar of Komnzo.
            \item[23.] Yakpo, Kofi. A grammar of Pichi.
            \end{enumerate}


            }
% 	\renewcommand{\lsISSN}{}
\fi
\ifx\lsSeries\classics
	\newcommand{\lsSeriesTitle}{Classics in Linguistics}
	\newcommand{\lsSeriesColor}{black}
	\renewcommand{\lsISSN}{2366-374X}
	\renewcommand{\lsSeriesText}{
            {\large Classics in Linguistics}

            \bigskip

            Chief Editors: Martin Haspelmath, Stefan Müller

            \bigskip

            In this series:

            \begin{enumerate}
            \item Lehmann, Christian. Thoughts on grammaticalization.
            \item Schütze, Carson T. The empirical base of linguistics: Grammaticality judgments and linguistic methodology.
            \item Bickerton, Derek. Roots of language.
            \item von der Gabelentz, Georg. Die Sprachwissenschaft.  Ihre Aufgaben, Methoden und bisherigen Ergebnisse.
            \item Stefan Müller, Marga Reis \& Frank Richter (Hrsg.). Beiträge zur deutschen Grammatik: Gesammelte Schriften von Tilman N.\ Höhle.
            \item Anderson, Stephen R.\ \& Louis de Saussure (eds.). René de Saussure and the theory of word formation.
            \item Wackernagel, Jacob. On a law of Indo-European word order: Über ein Gesetz der indogermanischen Wortstellung.
            \end{enumerate}
            }
\fi
\ifx\lsSeries\cmle
	\newcommand{\lsSeriesTitle}{Computational Models of Language Evolution}
	\newcommand{\lsSeriesColor}{lsNightBlue}
	\renewcommand{\lsISSN}{2364-7809}
	\renewcommand{\lsSeriesText}{
            {\large Computational Models of Language Evolution}

            \bigskip

            Editors: Luc Steels, Remi van Trijp

            \bigskip

            In this series:

            \begin{enumerate}
            \item Steels, Luc. The Talking Heads Experiment: Origins of words and meanings.
            \item Vogt, Paul. How mobile robots can self-organize a vocabulary.
            \item Bleys, Joris. Language strategies for the domain of colour.
            \item van Trijp, Remi. The evolution of case grammar.
            \item Spranger, Michael. The evolution of grounded spatial language.
            \end{enumerate}

            }
\fi
\ifx\lsSeries\eotms
	\newcommand{\lsSeriesTitle}{Empirically Oriented Theoretical \newlineCover Morphology and Syntax}
	\newcommand{\lsSeriesColor}{lsMidBlue}
	\renewcommand{\lsISSN}{2366-3529}
	\renewcommand{\lsSeriesText}{
            {\large Em­pir­i­cal­ly Ori­ent­ed The­o­ret­i­cal Mor­phol­o­gy and Syn­tax}

            \bigskip

            Chief Editor: Stefan Müller\\
            Consulting Editors: Berthold Crysmann, Ana R. Luís

            \bigskip

            In this series:

            \begin{enumerate}
            \item Lichte, Timm. Syntax und Valenz: Zur Modellierung kohärenter und elliptischer Strukturen mit Baumadjunktionsgrammatiken.
            \item Bîlbîie, Gabriela. Grammaire des constructions elliptiques: Une étude comparative des phrases sans verbe en roumain et en français.
            \item Bowern, Claire, Laurence Horn \& Raffaella Zanuttini (eds.). On looking into words (and beyond): Structures, Relations, Analyses.
            \item Bonami, Olivier, Gilles Boyé, Georgette Dal, Hélène Giraudo \& Fiammetta Namer. The lexeme in descriptive and theoretical morphology.
            \item Guzmán Naranjo, Matías. Analogical classification in formal grammar.
            \item Flick, Johanna. Die Entwicklung des Definitartikels im Althochdeutschen: Eine kognitiv-linguistische Korpusuntersuchung.
            \item Crysmann, Berthold \& Manfred Sailer (eds.). One-to-many relations in morphology, syntax, and semantics.
            \item Zinova, Yulia. Russian verbal prefixation: A frame semantic analysis.
            \item  Müller, Stefan, Anne Abeillé, Robert D. Borsley \& Jean-Pierre Koenig. Head-Driven Phrase Structure Grammar: The handbook.
	    \item Diewald, Gabriele \& Katja Politt (eds.). Paradigms regained: Theoretical and empirical arguments for the reassessment of the notion of paradigm.
	    \item Freywald, Ulrike,   Horst J. Simon   \& Stefan Müller (eds.). Headedness and/or grammatical anarchy?
            \end{enumerate}
            }
\fi
\ifx\lsSeries\eotmsig
	\newcommand{\lsSeriesTitle}{Implemented Grammars}
	\newcommand{\lsSeriesColor}{lsMidBlue}
\fi
\ifx\lsSeries\eurosla
	\newcommand{\lsSeriesTitle}{Eurosla Studies}
	\newcommand{\lsSeriesColor}{lsMidOrange}
	\renewcommand{\lsISSN}{2626-2665}

	\renewcommand{\lsSeriesText}{
            {\large  EuroSLA Studies}

            \bigskip

            Editor:
            Amanda Edmonds, Université Côte d'Azur\smallskip\\
            Associate editors:\\
            Gabriele Pallotti, University of Modena and Reggio Emilia\\
            Ineke Vedder, University of Amsterdam

            \bigskip

            In this series:

            \begin{enumerate}
            \item Pérez Vidal, Carmen, Sonia López-Serrano, Jennifer Ament \& Dakota J. Thomas-Wilhelm (eds.).  Learning context effects: Study abroad, formal instruction and international immersion classrooms
            \item Saturno, Jacopo. Utterance structure in initial L2 acquisition.
            \item Bardel, Camilla \& Laura Sánchez (eds.). Third language acquisition: Age, proficiency and multilingualism.
            \item  Edmonds, Amanda, Pascale Leclercq \& Aarnes Gudmestad (eds.), Interpreting  language-learning data.
            \item Berthele, Raphael \& Isabelle Udry (eds.). Individual differences in early instructed language learning: The role of language aptitude, cognition, and motivation.
            \item McManus, Kevin \& Monika S. Schmid (eds.). How special are early birds? Foreign language teaching and learning.
            \end{enumerate}
	}
\fi
\ifx\lsSeries\ela
        \newcommand{\elatitle}{Estudios de Lingüística Amerindia}
        \newcommand{\elaeditor}{Editores:}
        \newcommand{\elainthisseries}{En esta serie:}
	\newcommand{\lsSeriesTitle}{\elatitle}
	\newcommand{\lsSeriesColor}{lsMidDarkBlue}

	\renewcommand{\lsSeriesText}{
            {\large  \elatitle}

            \bigskip

            \elaeditor

    Carolina González. Florida State University\\
    Siri Tuttle. Navajo Technical University in New Mexico\\
    Thiago Chacon. University of Brasilia\\
    Heriberto Avelino. National Institute for Anthropology and History\\

            \bigskip

            \elainthisseries

            %\begin{enumerate}
            %\end{enumerate}
	}
\fi
\ifx\lsSeries\hpls
	\newcommand{\lsSeriesTitle}{History and Philosophy of the Language Sciences}
	\newcommand{\lsSeriesColor}{black}
	\renewcommand{\lsISSNelectronic}{2629-172X}
 	\renewcommand{\lsISSNprint}{2629-1711}
 	\renewcommand{\lsSeriesText}{
            {\large History and Philosophy of the Language Sciences}

            \bigskip

            Editor: James McElvenny


            \bigskip
            In this series:


            \small
            \begin{enumerate}
            \item McElvenny, James (ed.). Form and formalism in linguistics.
            \item Van Rooy, Raf. Greece’s labyrinth of language: A study in the early modern discovery of dialect diversity.
            \item Aussant, Émilie \& Jean-Michel Fortis. Historical journey in a linguistic archipelago: Case studies on concepts, fields, and commitments.
            \item McElvenny, James \& Ploder, Andrea. Holisms of communication: The early history of audio-visual sequence analysis.
            \item Anderson, Stephen R. Phonology in the Twentieth Century: Second edition, revised and expanded.
            \end{enumerate}
            \item McElvenny, James. Interviews in the history of linguistics: Volume I.


            }
\fi
\ifx\lsSeries\loc
        \newcommand{\lsSeriesTitle}{Languages of the Caucasus}
        \newcommand{\lsSeriesColor}{lsLightWine}
	\renewcommand{\lsISSNelectronic}{2699-0156}
 	\renewcommand{\lsISSNprint}{2699-0148}
 	\renewcommand{\lsSeriesText}{
                {\large Languages of the Caucasus}

                \bigskip

                Editors:        Diana Forker (Universität Jena),
                    Nina Dobrushina (National Research University Higher School of Economics, Moscow),
                    Timur Maisak (Institute of Linguistics at the Russian Academy of Sciences, Moscow),
                    Oleg Belyaev (Lomonosov Moscow State University).

                \bigskip

                In this series:

                \begin{enumerate}
                \item Daniel, Michael, Nina Dobrushina \& Dmitry Ganenkov (eds.). The Mehweb
                language: Essays on phonology, morphology and syntax.
                \item Forker, Diana. A grammar of Sanzhi Dargwa.

                \end{enumerate}
                }
\fi
\ifx\lsSeries\lv
        \newcommand{\lsSeriesTitle}{Language Variation}
        \newcommand{\lsSeriesColor}{lsDarkWine}
        \renewcommand{\lsISSN}{2366-7818}
            \renewcommand{\lsSeriesText}{
            {\large Language Variation}

            \bigskip

            Editors: John Nerbonne, Dirk Geeraerts

            \bigskip

            In this series:

            \begin{enumerate}
            \item Côté, Marie-Hélène, Remco Knooihuizen and John Nerbonne (eds.).  The future of dialects.
            \item Schäfer, Lea. Sprachliche Imitation: Jiddisch in der deutschsprachigen Literatur (18.–20. Jahrhundert).
            \item Juskan, Martin. Sound change, priming, salience: Producing and perceiving variation in Liverpool English.
            \item Dellert, Johannes. Information-theoretic causal inference of lexical flow.
            \item Zimmer, Christian (ed.). German(ic) in language contact: Grammatical and sociolinguistic dynamics.
            \item Tahmasebi, Nina, Lars Borin, Adam Jatowt, Yang Xu and Simon Hengchen (eds.). Computational approaches to semantic change.
            \item Paulsen, Ingrid. The emergence of American English as a discursive variety: Tracing enregisterment processes in nineteenth-century U.S. newspapers.
            \end{enumerate}
            }
\fi
\ifx\lsSeries\mi
	\newcommand{\lsSeriesTitle}{Morphological Investigations}
	\newcommand{\lsSeriesColor}{lsDarkGreenTwo}
	\renewcommand{\lsISSN}{2567-742X}
	\renewcommand{\lsSeriesText}{
            {\large Morphological Investigations}

            \bigskip

            Editors: Jim Blevins, Petar Milin, Michael Ramscar

            \bigskip

            In this series:

            \begin{enumerate}
            \item Trips, Carola \& Jaklin Kornfilt (eds.). Further investigations into the nature of phrasal compounding
            \item Baechler, Raffaela. Absolute Komplexität in der Nominalflexion.
            \item Schäfer, Martin. The semantic transparency of English compound nouns.
            \end{enumerate}

            }
\fi
\ifx\lsSeries\nc
	\newcommand{\lsSeriesTitle}{Niger-Congo Comparative Studies}
	\newcommand{\lsSeriesColor}{lsRed}
	\renewcommand{\lsISSNelectronic}{2627-0048}
 	\renewcommand{\lsISSNprint}{2626-3513}
 	\renewcommand{\lsSeriesText}{
            {\large Niger-Congo Comparative Studies}

            \bigskip

            Chief Editor:  Valentin Vydrin (INALCO – LLACAN, CNRS, Paris) \\
            Editors:
                Larry Hyman (University of California, Berkeley),
                Konstantin Pozdniakov (INALCO – LLACAN, CNRS, Paris),
                Guillaume Segerer (LLACAN, CNRS, Paris),
                John Watters (SIL International, Dallas, Texas).


            \bigskip

            In this series:

            \begin{enumerate}
            \item Watters, John R. (ed.). East Benue-Congo: Nouns, pronouns, and verbs.
            \item Pozdniakov, Konstantin. The numeral system of Proto-Niger-Congo: A step-by-step reconstruction.
            \item Pozdniakov, Konstantin. Proto-Fula–Sereer: Lexicon, morphophonology, and noun classes.
            \end{enumerate}



            }
\fi
\ifx\lsSeries\ogl
	\newcommand{\lsSeriesTitle}{Open Germanic Linguistics}
	\newcommand{\lsSeriesColor}{lsMidDarkBlue}
	\renewcommand{\lsISSNelectronic}{2750-557X} %online
	\renewcommand{\lsISSNprint}{2750-5588} %Print
	\renewcommand{\lsSeriesText}{
            {\large  Open Germanic Linguistics
            
            \bigskip
            
            Editors: 
            Michael T. Putnam,
            B. Richard Page,
            Laura Catharine Smith
            
            \bigskip
            
            In this series:
            
            \begin{enumerate}
            \item Lemke, Robin. Experimental investigations on the syntax and usage of fragments.
            \item Larsson, Ida \& Erik Petzell (eds.). Morphosyntactic change in Late Modern Swedish.
            \item Hall, Tracy Alan. Velar fronting in German dialects: A study in synchronic and diachronic phonology.
            \end{enumerate}
 }
         }
\fi
\ifx\lsSeries\ogs
	\newcommand{\lsSeriesTitle}{Open Generative Syntax}
	\newcommand{\lsSeriesColor}{lsDarkGreenOne}
	\renewcommand{\lsISSN}{2568-7336}
	\renewcommand{\lsSeriesText}{
            {\large Open Generative Syntax}

            \bigskip

            Editors:   Elena Anagnostopoulou,
                Mark Baker,
                Roberta D’Alessandro,
                David Pesetsky,
                Susi Wurmbrand


            \bigskip

            In this series:

            \begin{enumerate}
            \item Bailey, Laura R. \& Michelle Sheehan (eds.). Order and structure in syntax I: Word order and syntactic structure.
            \item Sheehan, Michelle \& Laura R. Bailey (eds.).  Order and structure in syntax II: Subjecthood and argument structure.
            \item Bacskai-Atkari, Julia. Deletion phenomena in comparative constructions: English comparatives in a cross-linguistic perspective.
            \item Franco, Ludovico, Mihaela Marchis Moreno \& Matthew Reeve (eds.). Agreement, case and locality in the nominal and verbal domains.
            \item Bross, Fabian. The clausal syntax of German Sign Language: A cartographic approach.
            \item Smith, Peter W., Johannes Mursell \& Katharina Hartmann (eds.). Agree to Agree: Agreement in the Minimalist Programme.
            \item Pineda, Anna \& Jaume Mateu (eds.). Dative constructions in Romance and beyond.
            \item Kastner, Itamar. Voice at the interfaces: The syntax, semantics, and morphology of the Hebrew verb.
            \item Bárány, András, Theresa Biberauer, Jamie Douglas \& Sten Vikner (eds.). Syntactic architecture and its consequences I: Syntax inside the grammar.
            \item Bárány, András, Theresa Biberauer, Jamie Douglas \& Sten Vikner (eds.). Syntactic architecture and its consequences II: Between syntax and morphology.
            \item Bárány, András, Theresa Biberauer, Jamie Douglas \& Sten Vikner (eds.). Syntactic architecture and its consequences III: Inside syntax.
            \item Laszakovits, Sabine \& Zheng Shen (eds.). The size of things I: Structure building.
            \end{enumerate}
            }
\fi
\ifx\lsSeries\orl
	\newcommand{\lsSeriesTitle}{Open Romance Linguistics}
	\newcommand{\lsSeriesColor}{lsDarkWine}
	\renewcommand{\lsISSNelectronic}{2940-1100} % Online
	\renewcommand{\lsISSNprint}{2940-1097}% (Print)
	\renewcommand{\lsSeriesText}{
            {\large Open Romance Linguistics}

            \bigskip

            \textbf{Editors:} \\
            Lorenzo Filipponio (HU Berlin)\\
            Richard Waltereit (HU Berlin)\\
            Esme Winter-Froemel (Julius-Maximilians-Universität Würzburg)\\
            Anne C. Wolfsgruber (HU Berlin)\\

            \bigskip

            \textbf{In this series:}

            \begin{enumerate}
            \item Kocher, Anna. Complementizers on edge: On the boundaries between syntax and pragmatics in Ibero-Romance.
            \item Bullock, Barbara E. Cinzia Russi \& Almeida Jacqueline Toribio (eds.). A half century of Romance linguistics: Selected proceedings of the 50th Linguistic Symposium on Romance Languages.
            \end{enumerate}
            }
\fi
\ifx\lsSeries\osl
	\newcommand{\lsSeriesTitle}{Open Slavic Linguistics}
	\newcommand{\lsSeriesColor}{lsMidGreen}
	\renewcommand{\lsISSNelectronic}{2627-8332} % Online
	\renewcommand{\lsISSNprint}{2627-8324}% (Print)
	\renewcommand{\lsSeriesText}{
            {\large Open Slavic Linguistics}

            \bigskip

            Editors: Berit Gehrke,
                    Denisa Lenertová,
                    Roland Meyer,
                    Radek Šimík \&
                    Luka Szucsich

            \bigskip

            In this series:

            \begin{enumerate}
            \item Lenertová, Denisa, Roland Meyer, Radek Šimík \& Luka Szucsich (Eds.). Advances in formal Slavic linguistics 2016.
            \item Wiland, Bartosz. The spell-out algorithm and lexicalization patterns: Slavic verbs and complementizers.
            \item Marušič, Franc, Petra Mišmaš  \& Rok Žaucer (eds.).  Advances in formal Slavic linguistics 2017.
            \item Blümel, Andreas, Jovana Gajić, Ljudmila Geist, Uwe Junghanns \&  Hagen Pitsch (eds.). Advances in formal Slavic linguistics 2018.
            \item Dočekal, Mojmír \& Marcin Wągiel (eds.). Formal approaches to number in Slavic and beyond.
            \item Wągiel, Marcin. Subatomic quantification.
            \item Kolaković, Zrinka, Edyta Jurkiewicz-Rohrbacher, Björn Hansen, Dušica Filipović Đurđević \& Nataša Fritz. Clitics in the wild: Empirical studies on the microvariation of the pronominal, reflexive and verbal clitics in Bosnian, Croatian and Serbian.
            \end{enumerate}
            }
\fi
\ifx\lsSeries\pmwe
	\newcommand{\lsSeriesTitle}{Phraseology and Multiword Expressions}
	\newcommand{\lsSeriesColor}{lsLightBlue}
	\renewcommand{\lsISSN}{2625-3127}
	\renewcommand{\lsSeriesText}{
            {\large Phraseology and Multiword Expressions}

            \bigskip

            Series editors:
                Agata Savary (University of Tours, Blois, France),
                Manfred Sailer (Goethe University Frankfurt a.\,M., Germany),
                Yannick Parmentier (University of Lorraine, France),
                Victoria Rosén (University of Bergen, Norway),
                Mike Rosner (University of Malta, Malta).

            \bigskip

            In this series:

            \begin{enumerate}
            \item Manfred Sailer \& Stella Markantonatou (eds.). Multiword expressions: Insights from a multilingual perspective.
            \item Stella Markantonatou, Carlos Ramisch, Agata Savary \& Veronika Vincze (eds.).  Multiword expressions at length and in depth: Extended papers from the MWE 2017 workshop.
            \item Yannick Parmentier \& Jakub Waszczuk (eds.). Representation and parsing of multiword expressions: Current trends.
            \item Schulte im Walde, Sabine \&    Eva Smolka (eds.).  The role of constituents in multiword expressions: An interdisciplinary, cross-lingual perspective.
            \item Trklja, Aleksandar \& Łukasz Grabowski (eds.). Formulaic language: Theories and methods.
            \end{enumerate}
            }
\fi
\ifx\lsSeries\rcg
	\newcommand{\lsSeriesTitle}{Research on Comparative Grammar}
	\newcommand{\lsSeriesColor}{lsDarkOrange}
	\renewcommand{\lsISSNelectronic}{2749-781X} %online
	\renewcommand{\lsISSNprint}{2749-7801} %Print
	\renewcommand{\lsSeriesText}{
            {\large Research on Comparative Grammar }

            \bigskip

            \textbf{Series editor}\\
                Martin Haspelmath (Max Planck Institute for Evolutionary Anthropology)


            In this series:

            \begin{enumerate}
                \item  Bahrt, Nicklas N. Voice syncretism.
                \item  Veselinova, Ljuba \& Arja Hamari (eds.). The Negative Existential Cycle.
            \end{enumerate}
            }
\fi
\ifx\lsSeries\scl
	\newcommand{\lsSeriesTitle}{Studies in Caribbean Languages}
	\newcommand{\lsSeriesColor}{lsDarkOrange}
	\renewcommand{\lsISSNelectronic}{2627-1834} %online
	\renewcommand{\lsISSNprint}{2627-1893} %Print
	\renewcommand{\lsSeriesText}{
            {\large Studies in Caribbean Languages}

            \bigskip

            Chief Editor: John R. Rickford\\
            Managing Editor: Joseph T. Farquharson

            \bigskip

            In this series:

            \begin{enumerate}
            \item Irvine-Sobers,  G. Alison. The acrolect in Jamaica: The architecture of phonological variation.
            \item Forbes-Barnett, Marsha. Dual aspectual forms and event structure in Caribbean English Creoles.
            \item Sherriah, André Ché. A tale of two dialect regions: Sranan’s 17th-century English input.
            \item Delgado, Sally.  Ship English: Sailors’ speech in the early colonial Caribbean.
            \end{enumerate}

            }
\fi
\ifx\lsSeries\sidl
	\newcommand{\lsSeriesTitle}{Studies in Diversity Linguistics}
	\newcommand{\lsSeriesColor}{lsRichGreen}
	\renewcommand{\lsISSN}{2363-5568}
	\renewcommand{\lsSeriesText}{
            {\large Studies in Diversity Linguistics}

            \bigskip

            Editor: Martin Haspelmath


            \bigskip
            In this series (see the complete series history at \url{https://langsci-press.org/catalog/series/sidl}): 

            \lsSeriesHistoryWheel{
            \item Handschuh, Corinna. A typology of marked-S languages.
            \item Rießler, Michael. Adjective attribution.
            \item Klamer, Marian (ed.). The Alor-Pantar languages: History and typology.
            \item Berghäll, Liisa. A grammar of Mauwake (Papua New Guinea).
            \item Wilbur, Joshua. A grammar of Pite Saami.
            \item Dahl, Östen. Grammaticalization in the North: Noun phrase morphosyntax in Scandinavian vernaculars.
            \item Schackow, Diana.    A grammar of Yakkha.
            \item Liljegren, Henrik. A grammar of Palula.
            \item Shimelman, Aviva. A grammar of Yauyos Quechua.
            \item Rudin, Catherine \& Bryan James Gordon (eds.). Advances in the study of Siouan languages and linguistics.
            \item Kluge, Angela. A grammar of Papuan Malay.
            \item Kieviet, Paulus. A grammar of Rapa Nui.
            \item Michaud, Alexis. Tone in Yongning Na: Lexical tones and morphotonology.
            \item Enfield, N.\,J. (ed.).  Dependencies in language: On the causal ontology of linguistic systems.
            \item Gutman, Ariel. Attributive constructions in North-Eastern Neo-Aramaic.
            \item Bisang, Walter \& Andrej Malchukov (eds.). Unity and diversity in grammaticalization scenarios.
            \item Stenzel, Kristine \& Bruna Franchetto (eds.). On this and other worlds: Voices from Amazonia.
            \item Paggio, Patrizia and Albert Gatt (eds.). The languages of Malta.
            \item Seržant, Ilja A.  \& Alena Witzlack-Makarevich (eds.). Diachrony of differential argument marking.
            \item Hölzl, Andreas. A typology of questions in Northeast Asia and beyond: An ecological perspective.
            \item Riesberg, Sonja,  Asako Shiohara \& Atsuko Utsumi (eds.). Perspectives on information structure in Austronesian languages.
            \item Döhler, Christian. A grammar of Komnzo.
            \item Yakpo, Kofi. A Grammar of Pichi.
            \item Guérin Valérie (ed.). Bridging constructions.
            \item Aguilar-Guevara, Ana,   Julia Pozas Loyo \&  Violeta Vázquez-Rojas Maldonado (eds.). Definiteness across languages.
            \item Di Garbo, Francesca, Bruno Olsson \& Bernhard Wälchli (eds.). Grammatical gender and linguistic complexity: Volume I: General issues and specific studies.
            \item Di Garbo, Francesca, Bruno Olsson \& Bernhard Wälchli (eds.). Grammatical gender and linguistic complexity: Volume II: World-wide comparative studies.
            \item Unterladstetter, Volker. Multi-verb constructions in Eastern Indonesia.
            \item Edwards, Owen. Metathesis and unmetathesis in Amarasi.
            \item Bergqvist, Henrik \& Seppo Kittilä (eds). Evidentiality, egophoricity, and engagement.
            \item Floyd, Simeon, Giovanni Rossi \& N. J. Enfield (eds.). Getting others to do things: A pragmatic typology of recruitments.
            \item Hölzl, Andreas  \& Thomas E. Payne. Tungusic languages: Past and present.
            \item Enke, Dankmar W., Larry M. Hyman, Johanna Nichols, Guido Seiler \& Thilo Weber (eds.). Language change for the worse.
            }
            }
\fi
\ifx\lsSeries\silp
	\newcommand{\lsSeriesTitle}{Studies in Laboratory Phonology}
	\newcommand{\lsSeriesColor}{lsLightWine}
	\renewcommand{\lsISSN}{2363-5576}
	\renewcommand{\lsSeriesText}{
            {\raggedleft\IfFileExists{labphon-logo.pdf}{\includegraphics[width=5cm]{labphon-logo.pdf}}{LabPhon-Logo}}

            \bigskip

            {\large Studies in Laboratory Phonology}

            \bigskip

            Chief Editor:  Martine Grice% (Chief Editor, University of Cologne, Germany),
            \\
            Editors:    Doris Mücke, % (University of Cologne, Germany),
                Taehong Cho % (Hanyang University, Seoul, South Korea)

            \bigskip

            In this series:

            \begin{enumerate}
            \item Cangemi, Francesco. Prosodic detail in Neapolitan Italian.
            \item Drager, Katie. Linguistic variation, identity construction, and cognition.
            \item Roettger, Timo B. Tonal placement in Tashlhiyt: How an intonation system accommodates to adverse phonological environments.
            \item Mücke, Doris. Dynamische Modellierung von Artikulation und prosodischer Struktur: Eine Einführung in die Artikulatorische Phonologie.
            \item Bergmann, Pia. Morphologisch komplexe Wörter im Deutschen: Prosodische Struktur und phonetische Realisierung.
            \item Feldhausen, Ingo \& Fliessbach, Jan \& Maria del Mar Vanrell. Methods in prosody: A Romance language perspective.
            \item Tilsen, Sam. Syntax with oscillators and energy levels.
            \item Ben Hedia, Sonia. Gemination and degemination in English affixation: Investigating the interplay between morphology, phonology and phonetics.
            \item Easterday, Shelece. Highly complex syllable structure: A typological and diachronic study.
            \item Roessig, Simon. Categoriality and continuity in prosodic prominence.
            \item Schmitz, Dominic. Production, perception, and comprehension of subphonemic detail: Word-Final /s/ in English.
            \end{enumerate}

            }
\fi
\ifx\lsSeries\tbls
	\newcommand{\lsSeriesTitle}{Textbooks in Language Sciences}
	\newcommand{\lsSeriesColor}{lsYellow}
	\renewcommand{\lsISSN}{2364-6209}
	\renewcommand{\lsSeriesText}{%
             {\large Textbooks in Language Sciences}
             
             \bigskip
             
             Editors: Stefan Müller, Antonio Machicao y Priemer\\
             Editorial Board: Claude Hagège, Marianne Mithun, Anatol Stefanowitsch, Foong Ha Yap
             
             \bigskip
             
             In this series:
             
             \begin{enumerate}
             \item Müller, Stefan. Grammatical theory: From transformational grammar to constraint-based approaches.
             \item Schäfer, Roland. Einführung in die grammatische Beschreibung des Deutschen.
             \item Freitas, Maria João \& Ana Lúcia Santos (eds.). Aquisição de língua materna e não materna: Questões gerais e dados do português.
             \item Roussarie, Laurent. Sémantique formelle: Introduction à la grammaire de Montague.
             \item Kroeger, Paul. Analyzing meaning: An introduction to semantics and pragmatics.
             \item Ferreira, Marcelo. Curso de semântica formal.
             \item Stefanowitsch, Anatol. Corpus linguistics: A guide to the methodology.
             \item Müller, Stefan. {\tblseight}.
             \item Hejná, Míša  \& George Walkden. A history of English.
             \item Kahane, Sylvain \& Kim Gerdes. Syntaxe théorique et formelle. Vol. 1: Modélisation, unités, structures.
             \item Freitas, Maria João, Marisa Lousada \& Dina Caetano Alves (eds.). Linguística clínica: Modelos, avaliação e intervenção.
             \end{enumerate}
             }
\fi
\ifx\lsSeries\tgdi
	\newcommand{\lsSeriesTitle}{Topics at the Grammar-Discourse \newlineCover Interface}
	\newcommand{\lsSeriesColor}{lsMidDarkBlue}
	\renewcommand{\lsISSN}{2567-3335}
	\renewcommand{\lsSeriesText}{
            {\large  Topics at the Grammar-Discourse Interface}

            \bigskip

            Editors: Philippa Cook (University of Göttingen),
            Anke Holler (University of Göttingen),
            Cathrine Fabricius-Hansen (University of Oslo)

            \bigskip

            In this series:

            \begin{enumerate}
            \item Song, Sanghoun. Modeling information structure in a cross-linguistic perspective.
            \item Müller, Sonja. Distribution und Interpretation von Modalpartikel-Kombinationen.
            \item Bueno Holle, Juan José. Information structure in Isthmus Zapotec narrative and conversation.
            \item Parikh, Prashant. Communication and content.
            \item Balogh, Kata, Anja Latrouite \& Robert D. Van Valin‚ Jr. (eds.) Nominal anchoring: Specificity, definiteness and article systems across languages.
            \item Næss, Åshild, Anna Margetts \& Yvonne Treis (eds.). Demonstratives in discourse.
	    \item Gergel, Remus \& Jonathan Watkins (eds.). Quantification and scales in change.
	    \item Nakagawa, Natsuko. Information structure in spoken Japanese: Particles, word order, and intonation.
            \end{enumerate}
            }
\fi
\ifx\lsSeries\tmnlp
	\newcommand{\lsSeriesTitle}{Translation and Multilingual Natural \newlineCover Language Processing}
	\newcommand{\lsSeriesColor}{lsDarkBlue}
	\renewcommand{\lsISSN}{2364-8899}
	\renewcommand{\lsSeriesText}{
            {\large Translation and Multilingual Natural Language Processing}

            \bigskip

            Editors: Oliver Czulo (Universität Leipzig),
            Silvia Hansen-Schirra (Johannes Gutenberg-Universität Mainz),
            Reinhard Rapp (Hochschule Magdeburg-Stendal),
            Mario Bisiada (Universitat Pompeu Fabra)

            \bigskip

            In this series (see the complete series history at \url{https://langsci-press.org/catalog/series/tmnlp}):
            
            \lsSeriesHistoryWheel[12]{
            \item Fantinuoli, Claudio \& Federico Zanettin (eds.). New directions in corpus-based translation studies.
            \item Hansen-Schirra, Silvia \& Sambor Grucza (eds.). Eyetracking and Applied Linguistics.
            \item Neumann, Stella, Oliver Čulo \& Silvia Hansen-Schirra (eds.). Annotation, exploitation and evaluation of parallel corpora: TC3\,I.
            \item Czulo, Oliver  \& Silvia Hansen-Schirra (eds.). Crossroads between Contrastive Linguistics, Translation Studies and Machine Translation: TC3\,II.
            \item Rehm, Georg, Felix Sasaki, Daniel Stein \& Andreas Witt (eds.). Language technologies for a multilingual Europe: TC3\,III.
            \item Menzel, Katrin, Ekaterina Lapshinova-Koltunski \& Kerstin Anna Kunz  (eds.). New perspectives on cohesion and coherence: Implications for translation.
            \item Hansen-Schirra, Silvia, Oliver Czulo \& Sascha Hofmann (eds). Empirical modelling of translation and interpreting.
            \item Svoboda, Tomáš, Łucja Biel \& Krzysztof Łoboda (eds.). Quality aspects in institutional translation.
            \item Fox, Wendy. Can integrated titles improve the viewing experience? Investigating the impact of subtitling on the reception and enjoyment of film using eye tracking and questionnaire data.
            \item Moran, Steven \& Michael Cysouw. The Unicode cookbook for linguists: Managing writing systems using orthography profiles.
            \item Fantinuoli, Claudio (ed.). Interpreting and technology.
            \item Nitzke, Jean. Problem solving activities in post-editing and translation from scratch: A multi-method study.
            \item Vandevoorde, Lore. Semantic differences in translation.
            \item Bisiada, Mario (ed.). Empirical studies in translation and discourse.
            \item Tra\&Co Group (ed.). Translation, interpreting, cognition: The way out of the box.
            \item Nitzke, Jean \& Silvia Hansen-Schirra. A short guide to post-editing.
            \item Hoberg, Felix. Informationsintegration in mehrsprachigen Textchats: Der Skype Translator im Sprachenpaar Katalanisch-Deutsch.
            \item Kenny, Dorothy (ed.). Machine translation for everyone: Empowering users in the age of artificial intelligence.
            \item Kajzer-Wietrzny, Marta, Adriano Ferraresi,   Ilmari Ivaska \& Silvia Bernardini. Mediated discourse at the European Parliament: Empirical investigations.
            \item Marzouk, Shaimaa. Sprachkontrolle im Spiegel der Maschinellen Übersetzung: Untersuchung zur Wechselwirkung ausgewählter Regeln der Kontrollierten Sprache mit verschiedenen Ansätzen der Maschinellen Übersetzung.
            \item Frittella, Francesca Maria. Usability research for interpreter-centred technology: The case study of SmarTerp.
            \item Prandi, Bianca. Computer-assisted simultaneous interpreting: A cognitive-experimental study on terminology.
            }
            }
\fi
\ifx\lsSeries\tpd
	\newcommand{\lsSeriesTitle}{Topics in Phonological Diversity}
	\newcommand{\lsSeriesColor}{lsDarkBlue}
	\renewcommand{\lsSeriesText}{
            {\large {Topics in Phonological Diversity}

            \bigskip

            Editors:     Natalia Kuznetsova (Università Cattolica del Sacro Cuore / Institute for Linguistic Studies, Russian Academy of Sciences)
            Cormac Anderson (MPI-SHH, Jena)
            Shelece Easterday (University of Hawai'i, Mānoa)


            \bigskip

            In this series:

            \begin{enumerate}
            \item ~
            \end{enumerate}
            }
        }
\fi
\ifx\lsSeries\dummyseries
	\newcommand{\lsSeriesTitle}{~}
	\newcommand{\lsSeriesColor}{lsNightGreen}
\fi
\ifx\lsSeries\guidelines
	\newcommand{\lsSeriesTitle}{Language Science Press Guidelines}
	\newcommand{\lsSeriesColor}{lsGuidelinesGray}
	\renewcommand{\lsCoverFontColor}{black}
\fi
}
