%%%==============================================================================
%% Copyright 2022-23 by Alceu Frigeri
%%
%% This work may be distributed and/or modified under the conditions of
%%
%% * The [LaTeX Project Public License](http://www.latex-project.org/lppl.txt),
%%   version 1.3c (or later), and/or
%% * The [GNU Affero General Public License](https://www.gnu.org/licenses/agpl-3.0.html),
%%   version 3 (or later)
%%
%% This work has the LPPL maintenance status *maintained*.
%%
%% The Current Maintainer of this work is Alceu Frigeri
%%
%% This is version 1.0.8 (2023/01/28)
%%
%% The list of files that compose this work can be found in the README.md file at
%% https://ctan.org/pkg/ufrgscca
%%
%%%==============================================================================
%% UFRGS stands for "Federal University of Rio Grande do Sul" in south Brazil
%% EE    stands for "Engineering School"
%% CCA   stands for "Control and Automation Engineering Course" (Portuguese acronym)
%%%==============================================================================
\makeatletter
\def\tc@tmp@packname{ufrgscca-en-core}
\def\tc@tmp@altpackname{ufrgsccaencore}
\def\tc@tmp@packdesc{UFRGS/CCA English core defs}
\def\tc@tmp@packdate{2023/01/28}
\def\tc@tmp@packversion{1.0.8}
\let\@exp\expandafter
\@exp\edef\csname\tc@tmp@altpackname version\endcsname{\tc@tmp@packversion}


\location{Porto~Alegre}{RS}

\university{Federal University of Rio Grande do Sul}
\universityacronym{UFRGS}
\universitydivision{Engineering School}
\divisiongradcouncil{\tcdef@cover@universitydivision Undergraduate Council}

\secretaryacronym{SACAD}
\secdivisionacronym{\tcdef@cover@secretaryacronym/EE}
\graduationtitle{Control and Automation Engineering}
\course{Control and Automation Engineering}
\courseacronym{CCA}
\coursecoord{current course coordinator}
\coursecoordtitle{Course Coordinator}
\advisorname{Advisor}%
\coadvisorname{Coadvisor}%
\examinername{Exam Committee}%

\reportspecificinfo{%
	Graduation Project presented to COMGRAD-\tcdef@cover@courseacronym\ of \tcdef@cover@university\
		in partial fulfillment of the requirements for the
		degree of \emph{\tcdef@cover@graduationtitle }.
}%

\approvalspecificinfo{%
		This Project was considered adequate for obtaining the
		credits of the course TCC (Diplom Project) of \emph{\tcdef@cover@course }
		and approved in its final form by the Advisor and the Examination Committee.
}%

\profname{Professor}
\coprofname{Professor}


