%%%==============================================================================
%% Copyright 2022-23 by Alceu Frigeri
%%
%% This work may be distributed and/or modified under the conditions of
%%
%% * The [LaTeX Project Public License](http://www.latex-project.org/lppl.txt),
%%   version 1.3c (or later), and/or
%% * The [GNU Affero General Public License](https://www.gnu.org/licenses/agpl-3.0.html),
%%   version 3 (or later)
%%
%% This work has the LPPL maintenance status *maintained*.
%%
%% The Current Maintainer of this work is Alceu Frigeri
%%
%% This is version 1.0.8 (2023/01/28)
%%
%% The list of files that compose this work can be found in the README.md file at
%% https://ctan.org/pkg/ufrgscca
%%
%%%==============================================================================
%% UFRGS stands for "Federal University of Rio Grande do Sul" in south Brazil
%% EE    stands for "Engineering School"
%% CCA   stands for "Control and Automation Engineering Course" (Portuguese acronym)
%%%==============================================================================
\makeatletter
\def\tc@tmp@packname{ufrgscca-en-forms}
\def\tc@tmp@altpackname{ufrgsccaenforms}
\def\tc@tmp@packdesc{UFRGS/CCA English forms defs}
\def\tc@tmp@packdate{2023/01/28}
\def\tc@tmp@packversion{1.0.8}
\let\@exp\expandafter
\@exp\edef\csname\tc@tmp@altpackname version\endcsname{\tc@tmp@packversion}


%%%%%%
%%%%%%
%%%%%% forms
%%%%%%
%%%%%%
%%%%%%

\formlocal{\tc@city,\hspace{4mm} de \hspace{1.2cm} de 20\hspace{4mm}.}

\formssignaturelabel{Assinatura}
\examinersignature{Assinatura\ \ d\tccore@@ref{examiner}{article}\ \ Avaliador\tccore@@ref{examiner}{narticle}}
\boardsignature{Assinatura\ \ do\ \ Membro\ \ da\ \ Banca}
\advisorsignature{Assinatura\ \ d\tccore@@ref{advisor}{article}\ \ Orientador\tccore@@ref{advisor}{narticle}}
\coadvisorsignature{Assinatura\ \ d\tccore@@ref{coadvisor}{article}\ \ Co-orientador\tccore@@ref{coadvisor}{narticle}}
\studentsignature{Assinatura\ \ d\tccore@@ref{student}{article}\ \ Alun\tccore@@ref{student}{article}}
\studentsignaturegen{Assinatura\ \ do(a)\ \ Aluno(a)}
\formsstudentlabel{Alun\tccore@@ref{student}{article}}
\formsstudentlabelgen{Aluno(a)}
\formproflabel{Professor(a)}
\profname{Professor\tccore@@ref{advisor}{narticle}}
\coprofname{Professor\tccore@@ref{coadvisor}{narticle}}
\formsboardlabel{Membro da Banca}
\formsadvisorlabel{Orientador\tccore@@ref{advisor}{narticle}}
\formsadvisorlabelgen{Orientador(a)}
\formscoadvisorlabel{Co-orientador\tccore@@ref{advisor}{narticle}}
\formsexaminerlabel{Avaliador\tccore@@ref{examiner}{narticle}}
\formsaltexaminerlabel{Suplente}
\formstimelabel{Horário}


%\formstopicAlabel{Conteúdo}
%\formstopicBlabel{Trabalho Escrito}
%\formstopicClabel{Apresentação}
\formsworktitlelabel{Título do Trabalho}
\formstemptitlelabel{Título Provisório}
\formsstudentIDlabel{Cartão}
\formsemaillabel{e-mail}
\formsphonelabel{ramal}
\agreelabel{De Acordo}

\continuelabel{Continua...}

\formsdatelabel{Data}
\formstitle{Trabalho de Conclusão de Curso em \tcdef@cover@course}
\formsfootnote{Entregar a cada membro da banca juntamente com a cópia do trabalho.}



\renewreqformtitle{Formulário de Renovação da Inscrição na Atividade de Ensino Trabalho de Conclusão em \tcdef@cover@course}

\renewreqformnotes{O resumo deve ser curto, i.e., não deve exceder este espaço. O texto deve ser escrito em parágrafo único, e por se tratar de proposta, poderá utilizar tempo futuro e não necessita ter motivação ou justificativa.\\
Deve conter:
\begin{enumerate*}[alpha)]
\item O QUE será feito - descrição e objetivos.
\item COMO será feito - metodologia.
\item Resultados esperados.
\end{enumerate*}
}

\reqformtitle{Formul\'{a}rio de Requerimento de Matr\'{i}cula}
\reqformopening{Ilm\tccore@@ref{coursecoord}{article}. Sr\tccore@@ref{coursecoord}{narticle}.\par
Coordenador\tccore@@ref{coursecoord}{narticle} da  Comissão de Graduação do Curso em \tcdef@cover@course  {da \tcdef@cover@universityacronym\ }}
%\reqformopening{algo}

\reqformdesc{\tccore@@ref{student}{Article} alun\tccore@@ref{student}{article} \tc@studentA , REGULARMENTE MATRICULAD\tccore@@ref{student}{Article} neste período letivo no curso \emph{\tcdef@cover@course\ }, desta universidade, portador\tccore@@ref{student}{narticle} do cartão de identificação n$^o$ \tc@studentAID\ vem por meio desta solicitar matrícula na atividade de ensino de \tcdef@forms@formstitle}

\coadvisorformtitle{Requerimento de Autorização de Co-Orientação}
\coadvisorformdesc{\tccore@@ref{student}{Article} alun\tccore@@ref{student}{article} \tc@studentA , REGULARMENTE MATRICULAD\tccore@@ref{student}{Article} na atividade de TCC neste período letivo, vem por meio desta solicitar autorização para registro de co-orientador de TCC, conforme justificativa abaixo.}

\formsbrieflabel{Resumo}

\formsstudentemaillabel{Email d\tccore@@ref{student}{article} Alun\tccore@@ref{student}{article}}

\formsadvisoremaillabel{Email d\tccore@@ref{advisor}{article} Orientador\tccore@@ref{advisor}{narticle}}

\formsreasonlabel{Justificativa}


\examformtitle{Formul\'{a}rio de Avalia\c{c}\~{a}o}

\examformdesc{A nota (variando de zero a dez) atribuída por cada membro da banca examinadora será dada considerando o desempenho d\tccore@@ref{student}{article} alun\tccore@@ref{student}{article} nos 3 pontos apresentados na tabela abaixo.}

\examformnoteslabel{Observações}

\examformnotes{\ \\Posteriormente, \tccore@@ref{TCCcoord}{article} professor\tccore@@ref{TCCcoord}{narticle} coordenador\tccore@@ref{TCCcoord}{narticle} calculará a nota final atribuída por cada membro da banca examinadora, de acordo com a seguinte ponderação:\\[2mm] {\bf Nota Final Banca = \tc@TCCpointAweight\ x \tc@TCCpointAlabel\  + \tc@TCCpointBweight\ x \tc@TCCpointBlabel\  + \tc@TCCpointCweight\ x \tc@TCCpointClabel\ } \\[2mm] A média final da atividade será dada pela média das notas finais (calculadas com a expressão acima) atribuidas por cada um dos membros da banca examinadora.}

\examboardformtitle{Formulário de Aprovação do Relatório Parcial e Banca Examinadora}

\examboardformdesc{Aprovo o Relatório Parcial e nominata da Banca Examinadora acima relacionada.}

\formsboardtitle{Banca Examinadora}

\advisorapprovalformtitle{Formulário de Aprovação para Apresentação}

\advisorapprovalformdesc{{\bf Parecer d\tccore@@ref{advisor}{article} Orientador\tccore@@ref{advisor}{narticle}}\footnote{Preenchimento Obrigatório}}

\advisorapprovalformdescB{Aprovo a versão final do trabalho submetido pel\tccore@@ref{student}{article} alun\tccore@@ref{student}{article} e considero \tccore@@ref{student}{article} mesm\tccore@@ref{student}{article} apt\tccore@@ref{student}{article} para apresentação.}

\rectifyapprovalformtitle{Formulário de Aprovação das Correções}

\rectifyapprovalformdesc{\begin{description}
\item[Observação 1:] A nota final será a já atribuída pela Banca Examinadora no momento da Defesa. Caso a versão final corrigida do trabalho mais este formulário não sejam entregues até a data estipulada, o conceito do aluno passará a ser {\bf D}.
\item[Observação 2:] A assinatura d\tccore@@ref{advisor}{article} orientador\tccore@@ref{advisor}{narticle} é obrigatória, entretanto a assinatura dos membros da banca só é necessária caso o(a) mesmo(a) tenha marcado a opção "$\Box$ Revisarei o trabalho depois de corrigido" no \emph{Formulário de Correções}.
\end{description}}

\receiptformtitle{Recibo de entrega de cópia da versão final do Trabalho de Conclusão}

\receiptformfootnote{Entregar a cada membro da banca juntamente com a cópia do trabalho final e após encaminhar ao \tcdef@cover@secretaryacronym .}

\receiptformdesc{Declaro que encontra-se em minha posse cópia da versão final do Trabalho de Conclusão de Curso em \tcdef@cover@course\  d\tccore@@ref{student}{article} alun\tccore@@ref{student}{article} }


\reviewformtitle{Formulário de Correções}
\reviewformdesc{Correções: \parbox[t]{.8\textwidth}{
\begin{description}[tcc,noitemsep]
\item[$\Box$] Nenhuma
\item[$\Box$] Ortográfica
\item[$\Box$] Regras de Escrita
\item[$\Box$] Equações
\item[$\Box$] Resumo
\item[$\Box$] Abstract
\item[$\Box$] Índice
\item[$\Box$] Introdução
\item[$\Box$] Conclusões
\item[$\Box$] Corpo do Trabalho
\item[$\Box$] Resultados
\item[$\Box$] Adicionar mais exemplos
\item[$\Box$] Figuras
\item[$\Box$] Tabelas
\item[$\Box$] {\bf Reescrever tudo}\footnotemark[2]
\item[$\Box$] Outras: \\
\begin{tabular}{p{0.7\textwidth}}
~\\\hline
~\\\hline
~\\\hline
~\\\hline
\end{tabular}\\[-1mm]
\item[$\Box$] {\bf Revisarei o trabalho depois de corrigido}%\footnotemark[2]
\end{description}}
}

\reviewformfootnoteB{Neste caso \tccore@@ref{student}{article} alun\tccore@@ref{student}{article} estará em EXAME e receberá conceito final C ou D, conforme revisão final do texto.}

\reviewformfootnote{\tcdef@forms@formsfootnote\ Após a apresentação, retornar este à coordenação do TCC.}

\formsrectifyOKdesc{Correções satisfatórias: \hspace*{1cm}$\Box$\ sim\hspace*{2cm}$\Box$\ não}

\TCCpointsweight{0.35}{0.35}{0.3}
\TCCpointslabel{Conteúdo}{Trab. Escrito}{Apresentação}
