%%%==============================================================================
%% Copyright 2022-23 by Alceu Frigeri
%%
%% This work may be distributed and/or modified under the conditions of
%%
%% * The [LaTeX Project Public License](http://www.latex-project.org/lppl.txt),
%%   version 1.3c (or later), and/or
%% * The [GNU Affero General Public License](https://www.gnu.org/licenses/agpl-3.0.html),
%%   version 3 (or later)
%%
%% This work has the LPPL maintenance status *maintained*.
%%
%% The Current Maintainer of this work is Alceu Frigeri
%%
%% This is version 1.0.8 (2023/01/28)
%%
%% The list of files that compose this work can be found in the README.md file at
%% https://ctan.org/pkg/ufrgscca
%%
%%%==============================================================================
%% UFRGS stands for "Federal University of Rio Grande do Sul" in south Brazil
%% EE    stands for "Engineering School"
%% CCA   stands for "Control and Automation Engineering Course" (Portuguese acronym)
%%%==============================================================================
\makeatletter
\def\tc@tmp@packname{ufrgscca-ptBR-forms}
\def\tc@tmp@altpackname{ufrgsccaptbrforms}
\def\tc@tmp@packdesc{UFRGS/CCA Portuguese forms defs}
\def\tc@tmp@packdate{2023/01/28}
\def\tc@tmp@packversion{1.0.8}
\let\@exp\expandafter
\@exp\edef\csname\tc@tmp@altpackname version\endcsname{\tc@tmp@packversion}


%%%%%%
%%%%%%
%%%%%% forms
%%%%%%
%%%%%%
%%%%%%

\formlocal{\tc@city,\hspace{4mm} de \hspace{1.2cm} de 20\hspace{4mm}.}

\formssignaturelabel{Assinatura}
\examinersignature{Assinatura\ \ d\tccore@@ref{examiner}{article}\ \ Avaliador\tccore@@ref{examiner}{narticle}}
\boardsignature{Assinatura\ \ do\ \ Membro\ \ da\ \ Banca}
\advisorsignature{Assinatura\ \ d\tccore@@ref{advisor}{article}\ \ Orientador\tccore@@ref{advisor}{narticle}}
\coadvisorsignature{Assinatura\ \ d\tccore@@ref{coadvisor}{article}\ \ Co-orientador\tccore@@ref{coadvisor}{narticle}}
\studentsignature{Assinatura\ \ d\tccore@@ref{student}{article}\ \ Alun\tccore@@ref{student}{article}}
\studentsignaturegen{Assinatura\ \ do(a)\ \ Aluno(a)}
\formsstudentlabel{Alun\tccore@@ref{student}{article}}
\formsstudentlabelgen{Aluno(a)}
\formproflabel{Professor(a)}
\profname{Professor\tccore@@ref{advisor}{narticle}}
\coprofname{Professor\tccore@@ref{coadvisor}{narticle}}
\formsboardlabel{Membro da Banca}
\formsadvisorlabel{Orientador\tccore@@ref{advisor}{narticle}}
\formsadvisorlabelgen{Orientador(a)}
\formscoadvisorlabel{Co-orientador\tccore@@ref{advisor}{narticle}}
\formsexaminerlabel{Avaliador\tccore@@ref{examiner}{narticle}}
\formsaltexaminerlabel{Suplente}
\formstimelabel{Horário}

\formssupervisorlabel{Supervisor\tccore@@ref{supervisor}{narticle}}


%\formstopicAlabel{Conteúdo}
%\formstopicBlabel{Trabalho Escrito}
%\formstopicClabel{Apresentação}
\formsworktitlelabel{Título do Trabalho}
\formstemptitlelabel{Título Provisório}
\formsstudentIDlabel{Cartão}
\formsemaillabel{e-mail}
\formsphonelabel{ramal}
\agreelabel{De Acordo}

\continuelabel{Continua...}

\formsdatelabel{Data}
\formstitle{Trabalho de Conclusão de Curso}% em  \tcdef@cover@course}
\formsfootnote{Entregar a cada membro da banca juntamente com a cópia do trabalho.}


\renewreqformtitle{Formulário de Renovação da Inscrição na Atividade de Ensino Trabalho de Conclusão em \tcdef@cover@course}

\renewreqformnotes{O resumo deve ser curto, i.e., não deve exceder este espaço. O texto deve ser escrito em parágrafo único, e por se tratar de proposta, poderá utilizar tempo futuro e não necessita ter motivação ou justificativa.\\
Deve conter:
\begin{enumerate*}[alpha)]
	\item O QUE será feito - descrição e objetivos.
   \item COMO será feito - metodologia.
	\item Resultados esperados.
\end{enumerate*}
}

\reqformtitle{Formul\'{a}rio de Requerimento de Matr\'{i}cula}
\reqformopening{Ilm\tccore@@ref{coursecoord}{article}. Sr\tccore@@ref{coursecoord}{narticle}.\par
 Coordenador\tccore@@ref{coursecoord}{narticle} da  Comissão de Graduação do Curso em \tcdef@cover@course\  {da \tcdef@cover@universityacronym\ }}
%\reqformopening{algo}

\reqformdescgen{\tccore@@ref{student}{Article} alun\tccore@@ref{student}{article} \tc@studentA , REGULARMENTE MATRICULAD\tccore@@ref{student}{Article} neste período letivo no curso \emph{\tcdef@cover@course\ }, desta universidade, portador\tccore@@ref{student}{narticle} do cartão de identificação n$^o$ \tc@studentAID\ vem por meio desta solicitar matrícula na atividade de ensino}


\reqformdesc{\tcdef@forms@reqformdescgen\ \tcdef@forms@formstitle}

\formsinternshiptitle{Estágio Supervisionado Obrigatório}% em \tcdef@cover@course}

\reqforminternshipdesc{\tcdef@forms@reqformdescgen\ \tcdef@forms@formsinternshiptitle}

\supervisorsignature{Assinatura\ \ d\tccore@@ref{supervisor}{article}\ \ Supervisor\tccore@@ref{supervisor}{narticle}}
\tutorsignature{Assinatura\ \ d\tccore@@ref{tutor}{article}\ \ Tutor\tccore@@ref{tutor}{narticle}}
\internshipcoordsignature{Assinatura\ \ d\tccore@@ref{internshipcoord}{article}\ \ Coordenador\tccore@@ref{internshipcoord}{narticle}}

\supervisorformtitle{Formulário de Avaliação do Supervisor (Pela Empresa)}
\tutorformtitle{Formulário de Avaliação do Tutor e Coordenador}

\interntutorgrade{Avaliação d\tccore@@ref{tutor}{article} Prof\tccore@@ref{tutor}{narticle}. Tutor\tccore@@ref{tutor}{narticle}:\emptybox}

\interncoordgrade{Avaliação d\tccore@@ref{internshipcoord}{article} Prof\tccore@@ref{internshipcoord}{narticle}. Coordenador\tccore@@ref{internshipcoord}{narticle}:\emptybox}


\reqforminternshipinfo{%
   \tcdef@forms@formsstudentemaillabel : {\bf \tc@studentAemail} %
\vspace{2mm}

Tutor : \tc@studentA@tutor%

Email do Tutor: {\bf \tccore@@ref{tutor}{email}}%
\hfill Ramal: {\bf \tccore@@ref{tutor}{phone}}%
\vspace{2mm}


Empresa: {\bf \tccore@@ref{internship}{company}}%

Área de Atividade: {\bf \tccore@@ref{internship}{field}}%
\vspace{2mm}

Supervisor\tccore@@ref{supervisor}{narticle}: {\bf \tccore@@ref{supervisor}{}} \hfill CREA: {\bf \tccore@@ref{supervisor}{register}}

Cargo: {\bf \tccore@@ref{supervisor}{office}}\hfill Email: {\bf \tccore@@ref{supervisor}{email}} \hfill Fone: {\bf \tccore@@ref{supervisor}{phone}}   %
\vspace{2mm}

Data de Início: {\bf \tccore@@ref{internship}{start}}\hfill Previsão de Término: {\bf \tccore@@ref{internship}{end}}\hfill Duração: {\bf \tccore@@ref{internship}{length}}
}

\internshipreqformnotes{O prazo final de entrega do relatório é até 21 dias antes do término do período letivo posterior à    inscrição na atividade. Relatórios não entregues até esta data serão considerados \textbf{\emph{Em Exame}}. Relatórios não entregues até 14 dias antes do término do período letivo considerado implicam a atribuição de \textbf{\emph{conceito FF}}, com o consequente encerramento do processo.}

\internshipstudentinfo{
    Aluno: \textbf{\tccore@@ref{student}{}}\hfill Cartão:\textbf{\tccore@@ref{student}{ID}}%
}
\internshipcompanyinfo{%
    Empresa: {\bf \tccore@@ref{internship}{company}}\\%
Área de Atividade: {\bf \tccore@@ref{internship}{field}}%
}
\internshipsupervisorinfo{
    Supervisor:  \textbf{\tccore@@ref{supervisor}{}} \hfill crea:\textbf{\tccore@@ref{supervisor}{register}}%
}
\internshiptutorinfo{
Tutor:  \textbf{\tccore@@ref{tutor}{}}%
}
\internshipcoordinfo{
Coordenador da Atividade:  \textbf{\tccore@@ref{internshipcoord}{}}%
}


\internshipperiod{
    Período do Estágio de: {\bf \tccore@@ref{internship}{start}} até: {\bf \tccore@@ref{internship}{end}}
}

\def\emptybox{\framebox[3em]{\color{white}W}}

\internsupervisorgradesform{
\begin{itemize}[tcc,nosep]
 \item Grupo I - Aspectos Profissionais
   \begin{enumerate}[tcc,nosep]
     \item \textbf{Qualidade do Trabalho}:\emptybox\\ {\footnotesize considerar a qualidade do trabalho tendo em vista o que seria desejável}
     \item \textbf{Engenhosidade}:\emptybox\\ {\footnotesize capacidade de sugerir, projetar ou executar modificações ou inovações.}
     \item \textbf{Conhecimentos}:\emptybox\\ {\footnotesize conhecimento demonstrado no desenvolvimento das atividades programadas.}
     \item \textbf{Cumprimentos das Tarefas}:\emptybox\\ {\footnotesize     considerar o volume de atividades cumpridas dentro de um padrão razoável.}
     \item \textbf{Iniciativa}:\emptybox\\ {\footnotesize iniciativa para desenvolver suas atividades sem dependências de outros.}
   \end{enumerate}
 \item Grupo II - Aspectos Humanos
    \begin{enumerate}[tcc,nosep]
     \item \textbf{Assiduidade}:\emptybox\\ {\footnotesize cumprimento do horário do estágio e ausência de falhas}
\item \textbf{Disciplina}:\emptybox\\ {\footnotesize observância das normas e regulamentos internos da empresa.}
\item \textbf{Sociabilidade}:\emptybox\\ {\footnotesize facilidade de se integrar com colegas e ambiente de trabalho.}
\item \textbf{Cooperação}:\emptybox\\ {\footnotesize     disposição para cooperar com colegas e para atender a atividades..}
\item \textbf{Senso de Responsabilidade}:\emptybox\\ {\footnotesize zelo pelo material, equipamentos e bens da empresa.}
    \end{enumerate}
\end{itemize}
}

\internsupervisorcomments{Considerações Complementares:}
\internshiptutorcomments{Considerações do Prof. Tutor sobre o Estágio:}
\internshipcoordcomments{Considerações Finais do Prof. Coordenador sobre o Estágio:}

\internsupervisornote{Favor utilizar a seguinte grade discreta: \begin{enumerate*}[start=0]\item Sofrível \item Regular \item Bom \item Muito Bom \item Excelente \end{enumerate*}
}
\coadvisorformtitle{Requerimento de Autorização de Co-Orientação}
\coadvisorformdesc{\tccore@@ref{student}{Article} alun\tccore@@ref{student}{article} \tc@studentA , REGULARMENTE MATRICULAD\tccore@@ref{student}{Article} na atividade de TCC neste período letivo, vem por meio desta solicitar autorização para registro de co-orientador de TCC, conforme justificativa abaixo.}

\formsbrieflabel{Resumo}

\formsstudentemaillabel{Email d\tccore@@ref{student}{article} Alun\tccore@@ref{student}{article}}

\formsadvisoremaillabel{Email d\tccore@@ref{advisor}{article} Orientador\tccore@@ref{advisor}{narticle}}

\formscoadvisoremaillabel{Email d\tccore@@ref{coadvisor}{article} Co-Orientador\tccore@@ref{coadvisor}{narticle}}

\formsreasonlabel{Justificativa}


\examformtitle{Formul\'{a}rio de Avalia\c{c}\~{a}o}

\examformdesc{A nota (variando de zero a dez) atribuída por cada membro da banca examinadora será dada considerando o desempenho d\tccore@@ref{student}{article} alun\tccore@@ref{student}{article} nos 3 pontos apresentados na tabela abaixo.}

\examformnoteslabel{Observações}

\examformnotes{\ \\Posteriormente, \tccore@@ref{TCCcoord}{article} professor\tccore@@ref{TCCcoord}{narticle} coordenador\tccore@@ref{TCCcoord}{narticle} calculará a nota final atribuída por cada membro da banca examinadora, de acordo com a seguinte ponderação:\\[2mm] {\bf Nota Final Banca = \tc@TCCpointAweight\ x \tc@TCCpointAlabel\  + \tc@TCCpointBweight\ x \tc@TCCpointBlabel\  + \tc@TCCpointCweight\ x \tc@TCCpointClabel\ } \\[2mm] A média final da atividade será dada pela média das notas finais (calculadas com a expressão acima) atribuidas por cada um dos membros da banca examinadora.}

\examboardformtitle{Formulário de Aprovação do Relatório Parcial e Banca Examinadora}

\examboardformdesc{Aprovo o Relatório Parcial e nominata da Banca Examinadora acima relacionada.}

\formsboardtitle{Banca Examinadora}

\advisorapprovalformtitle{Formulário de Aprovação para Apresentação}

\advisorapprovalformdesc{{\bf Parecer d\tccore@@ref{advisor}{article} Orientador\tccore@@ref{advisor}{narticle}}\footnote{Preenchimento Obrigatório}}

\advisorapprovalformdescB{Aprovo a versão final do trabalho submetido pel\tccore@@ref{student}{article} alun\tccore@@ref{student}{article} e considero \tccore@@ref{student}{article} mesm\tccore@@ref{student}{article} apt\tccore@@ref{student}{article} para apresentação.}

\rectifyapprovalformtitle{Formulário de Aprovação das Correções}

\rectifyapprovalformdesc{\begin{description}
\item[Observação 1:] A nota final será a já atribuída pela Banca Examinadora no momento da Defesa. Caso a versão final corrigida do trabalho mais este formulário não sejam entregues até a data estipulada, o conceito do aluno passará a ser {\bf D}.
\item[Observação 2:] A assinatura d\tccore@@ref{advisor}{article} orientador\tccore@@ref{advisor}{narticle} é obrigatória, entretanto a assinatura dos membros da banca só é necessária caso o(a) mesmo(a) tenha marcado a opção "$\Box$ Revisarei o trabalho depois de corrigido" no \emph{Formulário de Correções}.
\end{description}}

\receiptformtitle{Recibo de entrega de cópia da versão final do Trabalho de Conclusão}

\receiptformfootnote{Entregar a cada membro da banca juntamente com a cópia do trabalho final e após encaminhar ao \tcdef@cover@secretaryacronym .}

\receiptformdesc{Declaro que encontra-se em minha posse cópia da versão final do Trabalho de Conclusão de Curso em \tcdef@cover@course\  d\tccore@@ref{student}{article} alun\tccore@@ref{student}{article} }


\reviewformtitle{Formulário de Correções}
\reviewformdesc{Correções: \parbox[t]{.8\textwidth}{
	\begin{description}[tcc,noitemsep]
	\item[$\Box$] Nenhuma
	\item[$\Box$] Ortográfica
	\item[$\Box$] Regras de Escrita
	\item[$\Box$] Equações
	\item[$\Box$] Resumo
	\item[$\Box$] Abstract
	\item[$\Box$] Índice
	\item[$\Box$] Introdução
	\item[$\Box$] Conclusões
	\item[$\Box$] Corpo do Trabalho
	\item[$\Box$] Resultados
	\item[$\Box$] Adicionar mais exemplos
	\item[$\Box$] Figuras
	\item[$\Box$] Tabelas
	\item[$\Box$] {\bf Reescrever tudo}\footnotemark[2]
	\item[$\Box$] Outras: \\
	\begin{tabular}{p{0.7\textwidth}}
	~\\\hline
	~\\\hline
	~\\\hline
	~\\\hline
	\end{tabular}\\[-1mm]
	\item[$\Box$] {\bf Revisarei o trabalho depois de corrigido}%\footnotemark[2]
	\end{description}}
}

\reviewformfootnoteB{Neste caso \tccore@@ref{student}{article} alun\tccore@@ref{student}{article} estará em EXAME e receberá conceito final C ou D, conforme revisão final do texto.}

\reviewformfootnote{\tcdef@forms@formsfootnote\ Após a apresentação, retornar este à coordenação do TCC.}

\formsrectifyOKdesc{Correções satisfatórias: \hspace*{1cm}$\Box$\ sim\hspace*{2cm}$\Box$\ não}

\TCCpointsweight{0.35}{0.35}{0.3}
\TCCpointslabel{Conteúdo}{Trab. Escrito}{Apresentação}
